open Pendulum_data
open Misc

let static t = 0.05 (* s     *)
let static l = 10.0 (* m     *)
let static g = 10.0 (* m/s^2 *)
let static b = 0.5  (* 1/s *)
(* mass of the pendulum *)
let static m = 5.

let node integr dx = Misc.integr t dx
let node deriv x = Misc.deriv t x

(*
  equation of the pendulum	:
  - theta angle of the pendulum with Oy
  - d2x0,d2y0 second degree derivatives of the botom coordinates
  - l length of the pendulum
  - g acceleration  *)    
let node pendulum d2x0 d2y0 = theta where 
  rec theta = integr (integr ((sin thetap)*.(d2y0 +. g *. m) 
	 			-.(cos thetap)*.d2x0)/.l)
  and thetap = 0.0 fby theta
		       
(* second version with loss in energy *)
let node pendulum d2x0 d2y0 = theta where 
  rec theta = integr (integr ((sin thetap)*.(d2y0 +. g *. m) 
				-.(cos thetap)*.d2x0)/.l
			-. b *. thetap)
  and thetap = 0.0 -> pre theta
      
let node game x0 y0 =
(* pendulum controled by hand:        *)
(* x0, y0 are the botom coordinates   *)
  
(* derivation *)
  
  let d2x0 = deriv (deriv x0) in
  let d2y0 = deriv (deriv y0) in
  
(* pendulum *)
  
  let theta = pendulum d2x0 d2y0 in
  
(* geometry *)
  
  let x = x0 +. l*.(sin theta) in
  let y = y0 +. l*.(cos theta) in
  let p = make_pend x0 y0 x y in
  p
    
let node manual () =
  let x0,y0 = get_cursor () in
  let p = game x0 y0 in
  draw_pendulum p (p -> pre p)
